@@ -1,7 +1,7 @@
 HTMLWidgets.widget({
     name : "canvasXpress",
     type : "output",
-    
+
     factory: function(el, width, height) {
         var c = document.createElement('canvas');
         c.id = el.id + '-cx';
@@ -9,7 +9,7 @@ HTMLWidgets.widget({
         c.height = height;
 
         el.appendChild(c);
-        
+
         return {
             id: c.id,
             renderValue: function(x) {
@@ -25,6 +25,12 @@ HTMLWidgets.widget({
                 if (cx) {
                     cx.setDimensions(width, height);
                 }
+                else {
+                    cx = CanvasXpress.getObject(c.id + '-1');
+                    if (cx) {
+                        cx.setDimensions(width, height);
+                    }
+                }
             }
         };
     }
